function Points = chaos(trans,point,n)
% chaos(trans,point,n)
%
% function returns points generated by the chaos game
%
% trans - list of affine transformations
% point - starting point
% n - number of iterations
%
%
% example:
% point = [0 0 1];
% trans = {[0.4194 0.3629 -0.0000; 0.0376 0.3306 0.0000; 0 0 1.0000],...
%          [0.5645 -0.2903 0; 0.0699 0.1855 0.0000; 0.8500 0.8250 1.0000]};
% n = 1000;
% p = chaos(trans,point,n);

%computing the probabilities
det_i = zeros(1,length(trans));
pz = [];
det_p = 0;
for i = 1:length(trans)
    d = abs(det(trans{i}));
    det_i(i) = d;
    det_p = det_p + d;
    if d == 0
        pz = [pz i];
    end
end

if det_p == 0
    det_p = 1;
    det_i(:) = 1/length(trans);
end

pr = det_i / det_p;

if det_p > 0 && ~isempty(pz)
    pp = 0.008;
    pk = pp*length(pz)/(length(trans)-length(pz));
    for i = 1:length(trans)
        if ~isempty(find(pz == i))
           pr(i) = pp; 
        else
           pr(i) = pr(i) - pk;
        end
    end
end

p{1} = pr(1);
for i = 2:length(pr)
    p{i} = p{i-1} + pr(i);
end

%setting the starting point
pkt_t = point;
point_size = length(point);
points = zeros(point_size,n);

%chaos game
for i = 1:n
    r = rand(1);
    for j = 1:size(p,2)
        if r < p{j}
            pkt_t = pkt_t * trans{j};
            points(:,i) = pkt_t(:);
            break;
        end
    end
end

Points = points;